@@ -1,33 +1,29 @@
 #' @title AUC value calculate
 #'
-#' @param weight_table The weight data table of network
+#' @param network_table The weight data table of network
 #' @param ground_truth Ground truth for calculate AUC
 #' @param plot If true, draw and print figure of AUC
 #' @param line_color The color of line in the figure
 #' @param line_width The width of line in the figure
 #'
-#' @import patchwork
-#' @import ggplot2
-#'
 #' @return AUC values and figure
 #' @export
 #'
 #' @examples
-#' library(inferCSN)
 #' data("example_matrix")
 #' data("example_ground_truth")
-#' weight_table <- inferCSN(example_matrix)
-#' auc.calculate(weight_table, example_ground_truth, plot = TRUE)
+#' network_table <- inferCSN(example_matrix)
+#' auc.calculate(network_table, example_ground_truth, plot = TRUE)
 auc.calculate <- function(
-    weight_table,
+    network_table,
     ground_truth,
     plot = FALSE,
     line_color = "#1563cc",
     line_width = 1) {
-
   gold <- prepare.performance.data(
-    weight_table,
-    ground_truth)
+    network_table,
+    ground_truth
+  )
 
   auc_curves <- precrec::evalmod(
     scores = gold$weight,
@@ -43,7 +39,6 @@ auc.calculate <- function(
   auc_metric[1, "AUROC"] <- sprintf("%0.3f", auc$aucs[1])
   auc_metric[1, "AUPRC"] <- sprintf("%0.3f", auc$aucs[2])
   if (plot) {
-    # Separate data
     auroc_table <- subset(
       fortify(auc_curves),
       curvetype == "ROC"
@@ -53,7 +48,6 @@ auc.calculate <- function(
       curvetype == "PRC"
     )
 
-    # Plot
     auroc <- ggplot(auroc_table, aes(x = x, y = y)) +
       geom_line(
         color = line_color,
@@ -90,7 +84,6 @@ auc.calculate <- function(
       coord_fixed() +
       theme_bw()
 
-    # Combine two plots by `patchwork` package
     p <- auroc + auprc
     print(p)
   }
@@ -98,7 +91,7 @@ auc.calculate <- function(
   return(auc_metric)
 }
 
-#' ACC calculate
+#' @title ACC calculate
 #'
 #' @inheritParams auc.calculate
 #'
@@ -106,17 +99,16 @@ auc.calculate <- function(
 #' @export
 #'
 #' @examples
-#' library(inferCSN)
 #' data("example_matrix")
 #' data("example_ground_truth")
-#' weight_table <- inferCSN(example_matrix)
-#' acc.calculate(weight_table, example_ground_truth)
+#' network_table <- inferCSN(example_matrix)
+#' acc.calculate(network_table, example_ground_truth)
 acc.calculate <- function(
-    weight_table,
+    network_table,
     ground_truth) {
 
   gold <- prepare.performance.data(
-    weight_table,
+    network_table,
     ground_truth)
   results <- pROC::roc(
     gold$label ~ gold$weight,
@@ -157,11 +149,11 @@ acc.calculate <- function(
 #' @return Formated data
 #' @export
 prepare.performance.data <- function(
-    weight_table,
+    network_table,
     ground_truth) {
   # Check input data
-  colnames(weight_table) <- c("regulator", "target", "weight")
-  weight_table$weight <- abs(as.numeric(weight_table$weight))
+  colnames(network_table) <- c("regulator", "target", "weight")
+  network_table$weight <- abs(as.numeric(network_table$weight))
 
   if (ncol(ground_truth) > 2) ground_truth <- ground_truth[, 1:2]
   names(ground_truth) <- c("regulator", "target")
@@ -169,7 +161,7 @@ prepare.performance.data <- function(
 
   gold <- suppressWarnings(
     merge(
-      weight_table,
+      network_table,
       ground_truth,
       by = c("regulator", "target"),
       all.x = TRUE
