@@ -10,7 +10,7 @@
 
 
 inline void to_arma_error() {
-    Rcpp::stop("inferCSN.fit only supports sparse matricies (dgCMatrix), 2D arrays (Dense Matricies)");
+    Rcpp::stop("model.fit only supports sparse matricies (dgCMatrix), 2D arrays (Dense Matricies)");
 }
 
 #endif // RINTERFACE_H
